Reġistrazzjoni | OiRA

Temi

# Reġistrazzjoni

## Għaliex għandi nirreġistra?

L-ewwel ħaġa li tintalab tagħmel meta tibda l-ewwel valutazzjoni tar-riskji tiegħek hija li toħloq kont tal-OiRA - dan huwa proċess sempliċi u rapidu.

Ir-reġistrazzjoni tippermettilek tilloggja fi kwalunkwe ħin biex taċċessa d-data tiegħek, tkompli l-valutazzjonijiet preċedenti jew tibda oħrajn ġodda.

Ir-reġistrazzjoni tfisser li s-sistema tal-OiRA tista’ tissejvja s-sessjonijiet kollha tiegħek, u d-data tiegħek dejjem se tkun disponibbli.

Aqra l-politika tal-privatezza tagħna u sir af kif aħna nindirizzaw id-data personali tiegħek.

## X’inhi d-differenza bejn ir-reġistrazzjoni bħala utent u t-twettiq ta’ sessjoni ta’ test?

Is-sessjoni ta’ test tippermetti lill-partijiet interessati jagħtu ħarsa lejn l-għodda qabel ma jiddeċiedu li jirreġistraw. Madankollu, waqt sessjoni ta’ test, id-data tiegħek ma tiġix issejvjata, u inti ma tkun tista’ tirkupra l-ebda informazzjoni mdaħħla minnek fi stadju aktar tard. Is-sessjoni ta’ test ma tippermettilek tistampa l-ebda wieħed mir-rapporti, filwaqt li r-reġistrazzjoni tal-kont tiegħek tippermettilek tiddokumenta bis-sħiħ il-valutazzjoni tar-riskji tiegħek.

## Irreġistra għal kont ġdid

Din hija l-ewwel żjara tiegħek? Segwi dawn l-istadji sempliċi biex tibda:

1.) Ikklikkja fuq “Irreġistra” biex tara l-formola tar-reġistrazzjoni.

Formola tar-reġistrazzjoni.

2.) Daħħal l-indirizz tal-email tiegħek u agħżel password (darbtejn)

3.) Ikklikkja fuq “Li jmiss” biex tirreġistra l-kont il-ġdid tiegħek.

4.) Aqra u aċċetta l-politika ta’ privatezza biex tkompli

Issa se tkun illoggjat fis-sistema tal-OiRA.

## L-illoggjar f’kont eżistenti

Jekk tkun irreġistrajt qabel, dan huwa l-mod kif taċċessa l-kont tiegħek:

1.) Żur il-formola tal-illoggjar. Se tiġi tidher link għall-formola tal-illoggjar kull meta tipprova taċċessa l-OiRA, sakemm tkun illoggjajt.

Formola tal-illoggjar.

2.) Imla l-indirizz tal-email u l-password tiegħek.

3.) Illoggja billi tikklikkja l-buttuna “Login”.

Ladarba tilloggja, inti se tara l-iskrin ta’ hawn taħt. Minn hawnhekk tista’ tibda valutazzjoni tar-riskji ġdida jew tmur lura għal valutazzjonijiet tar-riskji li tkun bdejt qabel.

Id-daxxbord.

Ibda valutazzjoni tar-riskji ġdida billi tagħtiha titolu (eż. My-Company 2018-07-03) jew taċċessa waħda mill-valutazzjonijiet tar-riskji preċedenti tiegħek. Il-valutazzjonijiet tar-riskji kollha tiegħek jiġu ssejvjati għal referenza futura, sakemm ma tagħżilx li tħassarhom.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More